# soxspipe

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/soxspipe)](https://pypi.org/project/soxspipe/)  
[![](https://img.shields.io/pypi/v/soxspipe)](https://pypi.org/project/soxspipe/)  
[![](https://img.shields.io/github/license/thespacedoctor/soxspipe)](https://github.com/thespacedoctor/soxspipe)  
[![](https://img.shields.io/pypi/dm/soxspipe)](https://pypi.org/project/soxspipe/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=soxspipe%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/soxspipe/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=soxspipe%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/soxspipe/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/soxspipe@master/coverage.svg)](https://raw.githack.com/thespacedoctor/soxspipe/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/soxspipe/badge/?version=master)](https://soxspipe.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/soxspipe/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/soxspipe/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  





*The data-reduction pipeline for the SOXS instrument* (a python package with command-line tools).

Documentation for soxspipe is hosted by [Read the Docs](https://soxspipe.readthedocs.io/en/master/) (
[development version](https://soxspipe.readthedocs.io/en/develop/) and [master version](https://soxspipe.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/soxspipe). Please report any issues you find [here](https://github.com/thespacedoctor/soxspipe/issues).


## Features

* 

